==> haskell-base64-0.4.2.4-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-B1LPVzP4X3o75l7XMDGc3f
key:                  base64-0.4.2.4-B1LPVzP4X3o75l7XMDGc3f
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  973adb5747748e0919c72b44f740ef7b
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.2.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-B1LPVzP4X3o75l7XMDGc3f
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1 text-1.2.5.0
    text-short-0.1.5-38cFIZ7yE7mFr2Op6xM5rk

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base64-0.4.2.4-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-CiqWYqy6nV8LWmJgEUQV4x
key:                  base64-0.4.2.4-CiqWYqy6nV8LWmJgEUQV4x
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  c754a297af7d7a0078cfa9c9bce91e22
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.2.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-CiqWYqy6nV8LWmJgEUQV4x
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1 text-1.2.5.0
    text-short-0.1.6-BlBwhLn6RgVGU82Vvt7Q74

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
